@@ -564,6 +564,10 @@ class Account(AddressableAccount):
                 "BaseLocked": base_open_locked,
                 "QuoteUnsettled": quote_open_unsettled,
                 "QuoteLocked": quote_open_locked,
+                "BaseUnsettledInMarginBasket": base_open_unsettled if slot.index < len(self.in_margin_basket) and self.in_margin_basket[slot.index] else Decimal(0),
+                "BaseLockedInMarginBasket": base_open_locked if slot.index < len(self.in_margin_basket) and self.in_margin_basket[slot.index] else Decimal(0),
+                "QuoteUnsettledInMarginBasket": quote_open_unsettled if slot.index < len(self.in_margin_basket) and self.in_margin_basket[slot.index] else Decimal(0),
+                "QuoteLockedInMarginBasket": quote_open_locked if slot.index < len(self.in_margin_basket) and self.in_margin_basket[slot.index] else Decimal(0),
                 "PerpPositionSize": perp_position,
                 "PerpNotionalPositionSize": perp_notional_position,
                 "PerpValue": perp_value,
@@ -591,10 +595,11 @@ class Account(AddressableAccount):
         frame: pandas.DataFrame = pandas.DataFrame(asset_data)
         return frame
 
-    def weighted_assets(self, frame: pandas.DataFrame, weighting_name: str = "", include_unsettled_quote: bool = False) -> typing.Tuple[Decimal, Decimal]:
+    def weighted_assets(self, frame: pandas.DataFrame, weighting_name: str = "") -> typing.Tuple[Decimal, Decimal]:
         non_quote = frame.loc[frame["Symbol"] != self.shared_quote_token.symbol]
         quote = frame.loc[frame["Symbol"] == self.shared_quote_token.symbol, "SpotValue"].sum()
         quote += frame["PerpHealthQuote"].sum()
+        quote += frame["QuoteUnsettledInMarginBasket"].sum()
 
         assets = Decimal(0)
         liabilities = Decimal(0)
@@ -603,9 +608,6 @@ class Account(AddressableAccount):
         else:
             liabilities = quote
 
-        if include_unsettled_quote:
-            assets += frame["QuoteUnsettled"].sum()
-
         spot_value_key = f"Spot{weighting_name}Value"
         perp_value_key = f"Perp{weighting_name}HealthBaseValue"
 
@@ -634,22 +636,22 @@ class Account(AddressableAccount):
         return assets, liabilities
 
     def init_health(self, frame: pandas.DataFrame) -> Decimal:
-        assets, liabilities = self.weighted_assets(frame, "Init", include_unsettled_quote=False)
+        assets, liabilities = self.weighted_assets(frame, "Init")
         return assets + liabilities
 
     def maint_health(self, frame: pandas.DataFrame) -> Decimal:
-        assets, liabilities = self.weighted_assets(frame, "Maint", include_unsettled_quote=False)
+        assets, liabilities = self.weighted_assets(frame, "Maint")
         return assets + liabilities
 
     def init_health_ratio(self, frame: pandas.DataFrame) -> Decimal:
-        assets, liabilities = self.weighted_assets(frame, "Init", include_unsettled_quote=False)
+        assets, liabilities = self.weighted_assets(frame, "Init")
         if liabilities == 0:
             return Decimal(100)
 
         return ((assets / -liabilities) - 1) * 100
 
     def maint_health_ratio(self, frame: pandas.DataFrame) -> Decimal:
-        assets, liabilities = self.weighted_assets(frame, "Maint", include_unsettled_quote=False)
+        assets, liabilities = self.weighted_assets(frame, "Maint")
         if liabilities == 0:
             return Decimal(100)
 
