@@ -17,6 +17,7 @@ import argparse
 import typing
 
 from .afteraccumulateddepthelement import AfterAccumulatedDepthElement
+from .biasquantityonpositionelement import BiasQuantityOnPositionElement
 from .biasquoteelement import BiasQuoteElement
 from .biasquoteonpositionelement import BiasQuoteOnPositionElement
 from .chain import Chain
@@ -56,6 +57,7 @@ class ChainBuilder:
         # one specifies it.
         # Now add args for all the elements.
         AfterAccumulatedDepthElement.add_command_line_parameters(parser)
+        BiasQuantityOnPositionElement.add_command_line_parameters(parser)
         BiasQuoteElement.add_command_line_parameters(parser)
         BiasQuoteOnPositionElement.add_command_line_parameters(parser)
         ConfidenceIntervalElement.add_command_line_parameters(parser)
@@ -94,6 +96,8 @@ class ChainBuilder:
         proper_name: str = name.upper()
         if proper_name == "AFTERACCUMULATEDDEPTH":
             return AfterAccumulatedDepthElement.from_command_line_parameters(args)
+        elif proper_name == "BIASQUANTITYONPOSITION":
+            return BiasQuantityOnPositionElement.from_command_line_parameters(args)
         elif proper_name == "BIASQUOTE":
             return BiasQuoteElement.from_command_line_parameters(args)
         elif proper_name == "BIASQUOTEONPOSITION":
