@@ -29,14 +29,14 @@ from .reconciledorders import ReconciledOrders
 #
 class OrderReconciler(metaclass=abc.ABCMeta):
     def __init__(self) -> None:
-        self.logger: logging.Logger = logging.getLogger(self.__class__.__name__)
+        self._logger: logging.Logger = logging.getLogger(self.__class__.__name__)
 
     @abc.abstractmethod
     def reconcile(self, model_state: ModelState, existing_orders: typing.Sequence[mango.Order], desired_orders: typing.Sequence[mango.Order]) -> ReconciledOrders:
         raise NotImplementedError("OrderReconciler.reconcile() is not implemented on the base type.")
 
     def __str__(self) -> str:
-        return """« 𝙾𝚛𝚍𝚎𝚛𝚁𝚎𝚌𝚘𝚗𝚌𝚒𝚕𝚎𝚛 »"""
+        return """« OrderReconciler »"""
 
     def __repr__(self) -> str:
         return f"{self}"
@@ -57,4 +57,4 @@ class NullOrderReconciler(OrderReconciler):
         return outcomes
 
     def __str__(self) -> str:
-        return """« 𝙽𝚞𝚕𝚕𝙾𝚛𝚍𝚎𝚛𝚁𝚎𝚌𝚘𝚗𝚌𝚒𝚕𝚎𝚛 »"""
+        return """« NullOrderReconciler »"""
